MOONWELL_BASE = {
    "name": "MoonWell Lending Pool",
    "rewardToken": "",
    "comptrollerAddress": "0xfbb21d0380bee3312b33c4353c8936a0f13ef26c",
    "lensAddress": "",
    "poolToken": "0xa88594d404727625a9437c3f886c7643872296ae",
    "type": "LENDING_POOL",
    "forked": "compound",
    "reservesList": {
    }
}
